ContainerPositionExt

Trait ContainerPositionExt 

pub trait ContainerPositionExt: LayoutExt {
    // Provided method
    fn position(self, position: impl Into<Position>) -> Self { ... }
}
Method for setting how an element is placed relative to its parent or the window.

Provided Methods

fn position(self, position: impl Into<Position>) -> Self

Set how the element is placed relative to its parent or the window. See [Position].

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl ContainerPositionExt for GifViewer

Source

impl ContainerPositionExt for ImageViewer

Source

impl ContainerPositionExt for OverflowedContent

Source

impl ContainerPositionExt for ScrollView

Implementors



impl<T> ContainerPositionExt for T
where T: ContainerExt,